@@ -559,6 +559,20 @@ preferences_activated (GSimpleAction  *action,
 	gedit_show_preferences_dialog (window);
 }
 
+static void
+keyboard_shortcuts_activated (GSimpleAction *action,
+                              GVariant      *parameter,
+                              gpointer       user_data)
+{
+	GtkApplication *app;
+	GeditWindow *window;
+
+	app = GTK_APPLICATION (user_data);
+	window = GEDIT_WINDOW (gtk_application_get_active_window (app));
+
+	_gedit_cmd_help_keyboard_shortcuts (window);
+}
+
 static void
 help_activated (GSimpleAction *action,
                 GVariant      *parameter,
@@ -599,6 +613,7 @@ static GActionEntry app_entries[] = {
 	{ "new-window", new_window_activated, NULL, NULL, NULL },
 	{ "new-document", new_document_activated, NULL, NULL, NULL },
 	{ "preferences", preferences_activated, NULL, NULL, NULL },
+	{ "shortcuts", keyboard_shortcuts_activated, NULL, NULL, NULL },
 	{ "help", help_activated, NULL, NULL, NULL },
 	{ "about", about_activated, NULL, NULL, NULL },
 	{ "quit", quit_activated, NULL, NULL, NULL }
@@ -746,8 +761,6 @@ gedit_app_startup (GApplication *application)
 	GeditAppPrivate *priv;
 	GtkCssProvider *css_provider;
 	GtkSourceStyleSchemeManager *manager;
-	const gchar *dir;
-	gchar *icon_dir;
 #ifndef ENABLE_GVFS_METADATA
 	const gchar *cache_dir;
 	gchar *metadata_filename;
@@ -761,14 +774,6 @@ gedit_app_startup (GApplication *application)
 	gedit_debug_init ();
 	gedit_debug_message (DEBUG_APP, "Startup");
 
-	gedit_debug_message (DEBUG_APP, "Set icon");
-
-	dir = gedit_dirs_get_gedit_data_dir ();
-	icon_dir = g_build_filename (dir, "icons", NULL);
-
-	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), icon_dir);
-	g_free (icon_dir);
-
 	setup_theme_extensions (GEDIT_APP (application));
 
 #ifndef ENABLE_GVFS_METADATA
@@ -1447,7 +1452,7 @@ gedit_app_init (GeditApp *app)
 	priv = gedit_app_get_instance_private (app);
 
 	g_set_application_name ("gedit");
-	gtk_window_set_default_icon_name ("accessories-text-editor");
+	gtk_window_set_default_icon_name ("gedit");
 
 	priv->monitor = g_network_monitor_get_default ();
 	g_signal_connect (priv->monitor,
