@@ -28,7 +28,7 @@
 #include <glib/gi18n.h>
 #include <stdlib.h>
 
-#include "gedit-view-holder.h"
+#include "gedit-view-centering.h"
 #include "gedit-debug.h"
 #include "gedit-utils.h"
 #include "gedit-settings.h"
@@ -57,7 +57,7 @@ struct _GeditViewFrame
 	GSettings *editor_settings;
 
 	GeditView *view;
-	GeditViewHolder *view_holder;
+	GeditViewCentering *view_centering;
 	GtkFrame *map_frame;
 
 	SearchMode search_mode;
@@ -104,25 +104,6 @@ get_document (GeditViewFrame *frame)
 	return GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (frame->view)));
 }
 
-static void
-get_iter_at_start_mark (GeditViewFrame *frame,
-			GtkTextIter    *iter)
-{
-	GtkTextBuffer *buffer;
-
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (frame->view));
-
-	if (frame->start_mark != NULL)
-	{
-		gtk_text_buffer_get_iter_at_mark (buffer, iter, frame->start_mark);
-	}
-	else
-	{
-		g_warn_if_reached ();
-		gtk_text_buffer_get_start_iter (buffer, iter);
-	}
-}
-
 static void
 gedit_view_frame_dispose (GObject *object)
 {
@@ -356,8 +337,9 @@ start_search_finished (GtkSourceSearchContext *search_context,
 static void
 start_search (GeditViewFrame *frame)
 {
-	GtkSourceSearchContext *search_context;
 	GtkTextIter start_at;
+	GtkTextBuffer *buffer;
+	GtkSourceSearchContext *search_context;
 
 	g_return_if_fail (frame->search_mode == SEARCH);
 
@@ -368,7 +350,11 @@ start_search (GeditViewFrame *frame)
 		return;
 	}
 
-	get_iter_at_start_mark (frame, &start_at);
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (frame->view));
+
+	gtk_text_buffer_get_iter_at_mark (buffer,
+					  &start_at,
+					  frame->start_mark);
 
 	gtk_source_search_context_forward_async (search_context,
 						 &start_at,
@@ -1065,7 +1051,11 @@ update_goto_line (GeditViewFrame *frame)
 		return;
 	}
 
-	get_iter_at_start_mark (frame, &iter);
+	doc = get_document (frame);
+
+	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (doc),
+					  &iter,
+					  frame->start_mark);
 
 	split_text = g_strsplit (entry_text, ":", -1);
 
@@ -1112,7 +1102,6 @@ update_goto_line (GeditViewFrame *frame)
 
 	g_strfreev (split_text);
 
-	doc = get_document (frame);
 	moved = gedit_document_goto_line (doc, line);
 	moved_offset = gedit_document_goto_line_offset (doc, line, line_offset);
 
@@ -1206,13 +1195,17 @@ get_selected_text (GtkTextBuffer  *doc,
 static void
 init_search_entry (GeditViewFrame *frame)
 {
+	GtkTextBuffer *buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (frame->view));
+
 	if (frame->search_mode == GOTO_LINE)
 	{
 		gint line;
 		gchar *line_str;
 		GtkTextIter iter;
 
-		get_iter_at_start_mark (frame, &iter);
+		gtk_text_buffer_get_iter_at_mark (buffer,
+		                                  &iter,
+		                                  frame->start_mark);
 
 		line = gtk_text_iter_get_line (&iter);
 
@@ -1228,7 +1221,6 @@ init_search_entry (GeditViewFrame *frame)
 	else
 	{
 		/* SEARCH mode */
-		GtkTextBuffer *buffer;
 		gboolean selection_exists;
 		gchar *search_text = NULL;
 		gint selection_len = 0;
@@ -1251,8 +1243,6 @@ init_search_entry (GeditViewFrame *frame)
 			frame->old_search_text = g_strdup (frame->search_text);
 		}
 
-		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (frame->view));
-
 		search_context = get_search_context (frame);
 
 		if (search_context == NULL)
@@ -1427,7 +1417,7 @@ gedit_view_frame_class_init (GeditViewFrameClass *klass)
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-view-frame.ui");
 	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, view);
-	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, view_holder);
+	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, view_centering);
 	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, map_frame);
 	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, revealer);
 	gtk_widget_class_bind_template_child (widget_class, GeditViewFrame, search_entry);
@@ -1562,12 +1552,12 @@ gedit_view_frame_new (void)
 	return g_object_new (GEDIT_TYPE_VIEW_FRAME, NULL);
 }
 
-GeditViewHolder *
-gedit_view_frame_get_view_holder (GeditViewFrame *frame)
+GeditViewCentering *
+gedit_view_frame_get_view_centering (GeditViewFrame *frame)
 {
 	g_return_val_if_fail (GEDIT_IS_VIEW_FRAME (frame), NULL);
 
-	return frame->view_holder;
+	return frame->view_centering;
 }
 
 GeditView *
